@@ -45,30 +45,31 @@
 /******************************************************************
 IPv4 source used from Unix Network Programming by Richard STEVENS
  ******************************************************************/
-static int l2_inet_pton(int iFamily, const char *pszAddress, void *pvMemref)
+static int l2_inet_pton(int iFamily, const char *szAddress, void *pvMemref)
 {
-    int             i             = 0;
+    int             i            = 0;
     struct in_addr  IP4Addr;
     struct in6_addr IP6Addr;
-    const char      *pszIndex     = NULL;    /* To index IPv6 validity */
-    char            *pszNextfield = "";      /* For IPv6 address trans */
+    const char      *szIndex     = NULL;    /* To index IPv6 validity */
+    char            *szNextfield = "";      /* For IPv6 address trans */
 
+    assert(pvMemref != NULL);
     if (iFamily == AF_INET) {
-        if (inet_aton(pszAddress, &IP4Addr)) {
+        if (inet_aton(szAddress, &IP4Addr)) {
             memcpy(pvMemref, &IP4Addr, sizeof(struct in_addr));
             return 1; /* Success */
         }
         return 0;
     }
     else if (iFamily == AF_INET6) { /* Translate IPv6 addresses               */
-        pszIndex = pszAddress;      /* Initialize, verify in loop             */
-        for (i = 0; (i < 8) && pszNextfield; i++) { /* Iterate through fields */
+        szIndex = szAddress;        /* Initialize, verify in loop             */
+        for (i = 0; (i < 8) && szNextfield; i++) { /* Iterate through fields  */
             IP6Addr.__u6_addr.__u6_addr16[i] =\
-                ntohs((u_int16_t)strtol(pszIndex, &pszNextfield, 16));
-            pszIndex = pszNextfield + 1;
+                ntohs((u_int16_t)strtol(szIndex, &szNextfield, 16));
+            szIndex = szNextfield + 1;
         }
 
-        if ((i != 8) || (*pszNextfield))
+        if ((i != 8) || (*szNextfield))
             return 0;
         else { /* Success */
             memcpy(pvMemref, &IP6Addr, sizeof(struct in6_addr));
@@ -86,7 +87,7 @@ static int l2_inet_pton(int iFamily, const char *pszAddress, void *pvMemref)
 
 /* declare private channel configuration */
 typedef struct {
-    char *pszHost;           /* IP Address or name of host to connect to    */
+    char *szHost;            /* IP Address or name of host to connect to    */
     int  iFamily;            /* IP version to use, AF_INET4 or AF_INET6     */
     int  iProto;             /* Protocol to use, IPPROTO_TCP or IPPROTO_UDP */
     int  iPort;              /* TCP Port to connect to                      */
@@ -103,7 +104,7 @@ static l2_result_t hook_create(l2_context_t *ctx, l2_channel_t *ch)
         return L2_ERR_MEM;
 
     /* initialize configuration with reasonable defaults */
-    cfg->pszHost   = NULL;
+    cfg->szHost   = NULL;
     cfg->iFamily   = -1;
     cfg->iProto    = -1;
     cfg->iPort     = 0;
@@ -119,17 +120,40 @@ static l2_result_t hook_create(l2_context_t *ctx, l2_channel_t *ch)
 static l2_result_t hook_configure(l2_context_t *ctx, l2_channel_t *ch, const char *fmt, va_list ap)
 {
     l2_ch_socket_t *cfg = (l2_ch_socket_t *)ctx->vp;
+    char *szProtocol = NULL;
+    char *szFamily = NULL;
     l2_param_t pa[5];
     l2_result_t rv;
 
     /* feed and call generic parameter parsing engine */
-    L2_PARAM_SET(pa[0], ipversion, INT,     &cfg->iFamily);
-    L2_PARAM_SET(pa[1], protocol,  INT,     &cfg->iProto );
-    L2_PARAM_SET(pa[2], host,      CHARPTR, &cfg->pszHost);
-    L2_PARAM_SET(pa[3], port,      INT,     &cfg->iPort  );
+    L2_PARAM_SET(pa[0], ipversion, STRING,  szFamily);
+    L2_PARAM_SET(pa[1], protocol,  STRING,  szProtocol);
+    L2_PARAM_SET(pa[2], host,      CHARPTR, &cfg->szHost);
+    L2_PARAM_SET(pa[3], port,      INT,     &cfg->iPort);
     L2_PARAM_END(pa[4]);
     rv = l2_util_setparams(pa, fmt, ap);
 
+    /* translate incoming configuration parameters */
+    if (szFamily != NULL) {
+        if (strcmp(szFamily, "AF_INET6") == 0)
+            cfg->iFamily = AF_INET6;
+        else if (strcmp(szFamily, "AF_INET") == 0)
+            cfg->iFamily = AF_INET;
+        else
+            return L2_ERR_ARG;
+    }
+
+    if (szProtocol != NULL) {
+        if (strcmp(szProtocol, "IPPROTO_UDP") == 0)
+            cfg->iProto = IPPROTO_UDP;
+        else if (strcmp(szProtocol, "IPPROTO_TCP") == 0)
+            cfg->iProto = IPPROTO_TCP;
+        else
+            return L2_ERR_ARG;
+    }
+
+    free(szFamily);
+    free(szProtocol);
     return rv;
 }
 
@@ -142,7 +166,7 @@ static l2_result_t hook_open(l2_context_t *ctx, l2_channel_t *ch)
     struct sockaddr_in6 IP6Localsock, IP6Sockaddr;
 
     /* make sure a target is configured */
-    if (cfg->pszHost == NULL)
+    if (cfg->szHost == NULL)
         return L2_ERR_USE;
 
     /* open channel socket */
@@ -152,12 +176,12 @@ static l2_result_t hook_open(l2_context_t *ctx, l2_channel_t *ch)
         memset(&IP4Sockaddr,  0, sizeof(IP4Sockaddr));
 
         /* resolve host numerically */
-        if (l2_inet_pton(AF_INET, cfg->pszHost, &IP4Sockaddr.sin_addr.s_addr) == 1) {
+        if (l2_inet_pton(AF_INET, cfg->szHost, &IP4Sockaddr.sin_addr.s_addr) == 1) {
             IP4Sockaddr.sin_family = AF_INET;
             IP4Sockaddr.sin_port   = htons(cfg->iPort);
         }
         /* resolve host nominally */
-        else if ((pHostentry = gethostbyname(cfg->pszHost)) != NULL) {
+        else if ((pHostentry = gethostbyname(cfg->szHost)) != NULL) {
             if (pHostentry->h_addrtype == AF_INET) {
                 IP4Sockaddr.sin_family = AF_INET;
                 IP4Sockaddr.sin_port   = htons(cfg->iPort);
@@ -213,12 +237,12 @@ static l2_result_t hook_open(l2_context_t *ctx, l2_channel_t *ch)
         memset(&IP6Sockaddr,  0, sizeof(IP6Sockaddr));
 
         /* resolve host numerically */
-        if (l2_inet_pton(AF_INET6, cfg->pszHost, &IP6Sockaddr.sin6_addr.s6_addr) == 1) {
+        if (l2_inet_pton(AF_INET6, cfg->szHost, &IP6Sockaddr.sin6_addr.s6_addr) == 1) {
             IP6Sockaddr.sin6_family = AF_INET6;
             IP6Sockaddr.sin6_port   = htons(cfg->iPort);
         }
         /* resolve host nominally */
-        else if ((pHostentry = gethostbyname(cfg->pszHost)) != NULL) {
+        else if ((pHostentry = gethostbyname(cfg->szHost)) != NULL) {
             if (pHostentry->h_addrtype == AF_INET6) {
                 IP6Sockaddr.sin6_family = AF_INET6;
                 IP6Sockaddr.sin6_port   = htons(cfg->iPort);
