@@ -1,9 +1,38 @@
+/*
+**  Copyright (c) 2001 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2001 Cable & Wireless Deutschland <http://www.cw.com/de/>
+**
+**  This file is part of OSSP lmtp2nntp, an LMTP speaking local
+**  mailer which forwards mails as Usenet news articles via NNTP.
+**  It can be found at http://www.ossp.org/pkg/lmtp2nntp/.
+**
+**  This program is free software; you can redistribute it and/or
+**  modify it under the terms of the GNU General Public  License
+**  as published by the Free Software Foundation; either version
+**  2.0 of the License, or (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+**  General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this file; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+**  USA, or contact the OSSP project <ossp@ossp.org>.
+**
+**  msg.c: mail message manipulation library
+*/
 
 #include <stdlib.h>
+#include <stdio.h>
+
 #include "msg.h"
 #include "str.h"
 #include "argz.h"
-#include <stdio.h>
+
+/* third party */
+#include "l2.h"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -24,6 +53,7 @@ msg_t *msg_create(void)
     msg->cpMsg = NULL;
     msg->azHeaders = NULL;
     msg->asHeaders = 0;
+    msg->cpFid = NULL;
     msg->cpBody = NULL;
     msg->cpMsgid = NULL;
     msg->mail_from = NULL;
@@ -31,6 +61,7 @@ msg_t *msg_create(void)
     msg->asRcpt = 0;
     msg->azNewsgroups = NULL;
     msg->asNewsgroups = 0;
+    msg->l2 = NULL; /* this is a copy only */
 
     return msg;
 }
@@ -46,6 +77,8 @@ void msg_destroy(msg_t *msg)
         free(msg->cpMsg);
     if (msg->azHeaders != NULL)
         free(msg->azHeaders);
+    if (msg->cpFid != NULL)
+        free(msg->cpFid);
     if (msg->cpBody != NULL)
         free(msg->cpBody);
     if (msg->cpMsgid != NULL)
@@ -56,6 +89,7 @@ void msg_destroy(msg_t *msg)
         free(msg->azRcpt);
     if (msg->azNewsgroups != NULL)
         free(msg->azNewsgroups);
+    msg->l2 = NULL; /* this is a copy only, the "parent" needs to clean this up */
 
     free(msg);
     return;
@@ -100,42 +134,46 @@ msg_rc_t msg_split(msg_t *msg)
      * header information.
      */
 
-    /* split message into header and body */
+    log0(msg, DEBUG, "split message into header and body");
     if (str_parse(msg->cpMsg, "m/((?:.*?)\\n)\\n(.*)$/s", &cpHeaders, &msg->cpBody) <= 0)
         return MSG_ERR_SPLITHEADBODY;
 
     free(msg->cpMsg);
     msg->cpMsg = NULL;
 
-    /* replace envelope From w/o colon by X-F: pseudotag. This eliminates the
-     * special case of having one header, which is really an embedded
-     * envelope, not ending with a colon while all others do. After splitting
-     * headers into name and value pairs this envelope ist stripped off.
+    log0(msg, DEBUG, "replace envelope From w/o colon by X-F: pseudotag");
+    /* This eliminates the special case of having one header, which is really
+     * an embedded envelope, not ending with a colon while all others do.
+     * After splitting headers into name and value pairs this envelope ist
+     * stripped off.
      */
     if (strncasecmp(cpHeaders, "From", 4) == 0)
         memcpy(cpHeaders, "X-F:", 4);
 
-    /* unwrap header lines */
+    log0(msg, DEBUG, "unwrap header lines");
     /* poor man's s///g simulator as current str library doesn't support global substitution */
     while (str_parse(cpHeaders, "s/(.*?)\\n[ \\t]+(.*)/$1 $2/s", &cpRem) > 0) {
         free(cpHeaders);
         cpHeaders = cpRem;
     }
 
-    /* split header lines into names and values */
-    while (str_parse(cpHeaders, "m/^([\\w-]+?:)[ \\t]*([^\\n]*?)[ \\t]*\\n(.*)/s", &cpName, &cpValue, &cpRem) > 0) {
+    log0(msg, DEBUG, "split header lines into names and values");
+    while (str_parse(cpHeaders, "m/^[> \\t]*([\\x21-\\x7e]+?:)[ \\t]*([^\\n]*?)[ \\t]*\\n(.*)/s", &cpName, &cpValue, &cpRem) > 0) {
         free(cpHeaders);
         cpHeaders = cpRem;
         argz_add(&msg->azHeaders, &msg->asHeaders, cpName);
         argz_add(&msg->azHeaders, &msg->asHeaders, cpValue);
+        free(cpName);
+        free(cpValue);
     }
 
-    /* check for headers we care about and do whatever neccessary */
+    log0(msg, DEBUG, "check for headers we care about and do whatever neccessary");
     msg->cpMsgid = NULL;
     msg->azNewsgroups = NULL;
     msg->asNewsgroups = 0;
     cp = msg->azHeaders;
     while (cp != NULL) {
+        log1(msg, DEBUG, "processing header \"%s\"", cp);
         if (strcasecmp("X-F:", cp) == 0) {
             argz_delete(&msg->azHeaders, &msg->asHeaders, cp);             /* del  name  */
             argz_delete(&msg->azHeaders, &msg->asHeaders, cp);             /* del  value */
@@ -148,6 +186,9 @@ msg_rc_t msg_split(msg_t *msg)
         }
         if (strcasecmp("Received:", cp) == 0) {
             argz_delete(&msg->azHeaders, &msg->asHeaders, cp);             /* del  name  */
+            if ((msg->cpFid == NULL) &&
+                (str_parse(cp, "m/\\sid\\s+<?([\\w\\d]{1,30})/i", &msg->cpFid) > 0))
+                    log1(msg, DEBUG, "found foreign-ID \"%s\" for logging", msg->cpFid);
             argz_delete(&msg->azHeaders, &msg->asHeaders, cp);             /* del  value */
             continue;
         }
@@ -184,17 +225,23 @@ msg_rc_t msg_split(msg_t *msg)
         if ((cp = argz_next(msg->azHeaders, msg->asHeaders, cp)) == NULL)  /* next name  */
             break;
     }
+
+    log0(msg, DEBUG, "checking Message-ID");
     if (msg->cpMsgid == NULL)
         return MSG_ERR_SPLITIDNONE;
 
+    log0(msg, DEBUG, "checking Newsgroups");
     if (msg->azNewsgroups != NULL) {
         argz_stringify(msg->azNewsgroups, msg->asNewsgroups, ',');
         if (argz_create_sep(msg->azNewsgroups, ',', &msg->azNewsgroups, &msg->asNewsgroups) != 0)
             return MSG_ERR_MEM;
     }
-    argz_add(&msg->azHeaders, &msg->asHeaders, "Path:");
-    argz_add(&msg->azHeaders, &msg->asHeaders, "not-for-mail");
 
+    log0(msg, DEBUG, "adding mandatory Path: header");
+    argz_add(&msg->azHeaders, &msg->asHeaders, "Path:");
+    argz_add(&msg->azHeaders, &msg->asHeaders, "lmtp2nntp!not-for-mail");
+
+    log0(msg, DEBUG, "split complete");
     return MSG_OK;
 }
 
@@ -211,8 +258,10 @@ msg_rc_t msg_join(msg_t *msg)
     char         cOld;
     int          n;
     char        *cpHeaders;
+    char        *azNewheaders;
+    size_t       asNewheaders;
 
-    /* verify asNewsgroups */
+    log0(msg, DEBUG, "verify Newsgroups");
     if (msg->azNewsgroups == NULL)
         return MSG_ERR_JOINGROUPNONE;
     argz_stringify(msg->azNewsgroups, msg->asNewsgroups, ',');
@@ -221,7 +270,7 @@ msg_rc_t msg_join(msg_t *msg)
     argz_add(&msg->azHeaders, &msg->asHeaders, "Newsgroups:");
     argz_add(&msg->azHeaders, &msg->asHeaders, msg->azNewsgroups);
 
-    /* verify Message-ID */
+    log0(msg, DEBUG, "verify Message-ID");
     if (msg->cpMsgid == NULL)
         return MSG_ERR_JOINIDNONE;
     if (strlen(msg->cpMsgid) == 0)
@@ -229,7 +278,7 @@ msg_rc_t msg_join(msg_t *msg)
     argz_add(&msg->azHeaders, &msg->asHeaders, "Message-ID:");
     argz_add(&msg->azHeaders, &msg->asHeaders, msg->cpMsgid);
 
-    /* merge name/value pairs into single string */
+    log0(msg, DEBUG, "merge name/value pairs into single string");
     argz_add(&msg->azHeaders, &msg->asHeaders, ""); /* append empty string */
     if ((aHeaders = (char **)malloc((argz_count(msg->azHeaders, msg->asHeaders) + 1) * sizeof(char *))) == NULL)
         return MSG_ERR_MEM;
@@ -247,9 +296,8 @@ msg_rc_t msg_join(msg_t *msg)
     }
     free(aHeaders);
 
-    /* fold headers
-     *
-     * A logical line is split into one or more physical '\n'-terminated
+    log0(msg, DEBUG, "fold headers");
+    /* A logical line is split into one or more physical '\n'-terminated
      * lines. The physical line is never longer than WRAPAT characters. This
      * includes the folded data and the header name + colon + space for the
      * first line and WRAPUSING string prefix for all other lines. Leading and
@@ -258,6 +306,8 @@ msg_rc_t msg_join(msg_t *msg)
      * Fragments exceeding WRAPAT characters without having a blank as a
      * splitting point are forcibly cut at a non-blank character.
      */
+    azNewheaders = NULL;
+    asNewheaders = 0;
     cp = NULL;
     while ((cp = argz_next(msg->azHeaders, msg->asHeaders, cp)) != NULL) {
         if (strlen(cp) > WRAPAT) {
@@ -295,12 +345,20 @@ msg_rc_t msg_join(msg_t *msg)
                 strcat(cpWrap, WRAPUSING);
                 strcat(cpWrap, cpRem);
             }
-            argz_delete(&msg->azHeaders, &msg->asHeaders, cp);
-            argz_insert(&msg->azHeaders, &msg->asHeaders, cp, cpWrap);
+            argz_add(&azNewheaders, &asNewheaders, cpWrap);
+            log2(msg, DEBUG, "a folded header \"%{text}D\"", cpWrap, strlen(cpWrap));
             free(cpWrap);
         }
+        else {
+            argz_add(&azNewheaders, &asNewheaders, cp);
+            log2(msg, DEBUG, "verbatim header \"%{text}D\"", cp, strlen(cp));
+        }
     }
+    free(msg->azHeaders);
+    msg->azHeaders = azNewheaders;
+    msg->asHeaders = asNewheaders;
 
+    log0(msg, DEBUG, "strigify headers");
     argz_stringify(msg->azHeaders, msg->asHeaders, '\n');
     cpHeaders = msg->azHeaders;
 
@@ -308,6 +366,7 @@ msg_rc_t msg_join(msg_t *msg)
      * header + CRLF + body + '.' + CRLF + NUL, replacing NL with CRLF *
      ********************************************************************/
 
+    log0(msg, DEBUG, "assemble header and body");
     n = 0;
     /* count size of headers, reserve space for NL to CRLF conversion */
     for (i = 0; ((c = cpHeaders[i]) != NUL); i++) {
@@ -375,6 +434,7 @@ msg_rc_t msg_join(msg_t *msg)
     msg->cpMsg[n++] = '\n';
     msg->cpMsg[n]   = NUL;
 
+    log0(msg, DEBUG, "join complete");
     return MSG_OK;
 }
 
